@@ -23,6 +23,10 @@
 
 #include <octave/oct.h>
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 enum cyclic_poly_type
 {
   CYCLIC_POLY_MIN=0,
@@ -38,7 +42,7 @@ filter_gf2 (const Array<int>& b, const Array<int>& a,
             const Array<int>& x, const int& n)
 {
 
-  int x_len = x.length ();
+  int x_len = x.numel ();
   Array<int> si (dim_vector (n, 1), 0);
   Array<int> y (dim_vector (x_len, 1), 0);
 
@@ -217,8 +221,8 @@ is @code{\"polynomial\"}.\n\
       for (unsigned long long i = (1UL<<m)+1; i < (1UL<<(1+m)); i+=2)
         if (do_is_cyclic_polynomial (i, n, m))
           {
-            cyclic_polys.resize (cyclic_polys.length ()+1);
-            cyclic_polys(cyclic_polys.length ()-1) = (double)i;
+            cyclic_polys.resize (cyclic_polys.numel ()+1);
+            cyclic_polys(cyclic_polys.numel ()-1) = (double)i;
           }
       break;
     case CYCLIC_POLY_L:
@@ -233,8 +237,8 @@ is @code{\"polynomial\"}.\n\
             {
               if (do_is_cyclic_polynomial (i, n, m))
                 {
-                  cyclic_polys.resize (cyclic_polys.length ()+1);
-                  cyclic_polys(cyclic_polys.length ()-1) = (double)i;
+                  cyclic_polys.resize (cyclic_polys.numel ()+1);
+                  cyclic_polys(cyclic_polys.numel ()-1) = (double)i;
                 }
             }
         }
@@ -244,7 +248,7 @@ is @code{\"polynomial\"}.\n\
       break;
     }
 
-  if (cyclic_polys.length () == 0)
+  if (cyclic_polys.numel () == 0)
     {
       octave_stdout <<
         "cyclpoly: no generator polynomial statifies constraints" << std::endl;
@@ -254,8 +258,8 @@ is @code{\"polynomial\"}.\n\
     {
       if (polyrep)
         {
-          Matrix polys (cyclic_polys.length (), m+1, 0);
-          for (int i = 0 ; i < cyclic_polys.length (); i++)
+          Matrix polys (cyclic_polys.numel (), m+1, 0);
+          for (int i = 0 ; i < cyclic_polys.numel (); i++)
             for (int j = 0; j < m+1; j++)
               if ((unsigned long long)cyclic_polys(i) & (1<<j))
                 polys(i, j) = 1;
