@@ -21,9 +21,18 @@
 #if !defined (octave_galois_int_h)
 #define octave_galois_int_h 1
 
-#include <octave/config.h>
-#include <octave/base-lu.h>
+#include <octave/oct.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 #include <octave/mx-base.h>
+#include <octave/ov-typeinfo.h>
+
+#ifdef HAVE_OCTAVE_BASE_LU_H
+# include <octave/base-lu.h>
+#else
+# include "base-lu.h"
+#endif
 
 #include "galoisfield.h"
 
@@ -151,13 +160,22 @@ private:
   pivot_type ptype;
 };
 
+#ifndef DEFMETHOD_DLD
 void install_gm_gm_ops (void);
 void install_gm_m_ops (void);
 void install_m_gm_ops (void);
 void install_gm_s_ops (void);
 void install_s_gm_ops (void);
 void install_fil_gm_ops (void);
-
+#else
+void install_gm_gm_ops (octave::type_info& ti);
+void install_gm_m_ops (octave::type_info& ti);
+void install_m_gm_ops (octave::type_info& ti);
+void install_gm_s_ops (octave::type_info& ti);
+void install_s_gm_ops (octave::type_info& ti);
+void install_fil_gm_ops (octave::type_info& ti);
+#endif
+ 
 galois elem_pow (const galois& a, const galois& b);
 galois elem_pow (const galois& a, const Matrix& b);
 galois elem_pow (const galois& a, double b);
