@@ -18,6 +18,10 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "galois.h"
 #include "galoisfield.h"
 #include "galois-def.h"
