@@ -180,55 +180,50 @@ make_gdiag (const octave_value& a, const octave_value& b)
       galois m = ((const octave_galois&) a.get_rep ()).galois_value ();
       int k = b.nint_value ();
 
-      if (! error_state)
+      int nr = m.rows ();
+      int nc = m.columns ();
+
+      if (nr == 0 || nc == 0)
+        retval = new octave_galois (m);
+      else if (nr == 1 || nc == 1)
         {
-          int nr = m.rows ();
-          int nc = m.columns ();
-
-          if (nr == 0 || nc == 0)
-            retval = new octave_galois (m);
-          else if (nr == 1 || nc == 1)
+          int roff = 0;
+          int coff = 0;
+          if (k > 0)
             {
-              int roff = 0;
-              int coff = 0;
-              if (k > 0)
-                {
-                  roff = 0;
-                  coff = k;
-                }
-              else if (k < 0)
-                {
-                  k = -k;
-                  roff = k;
-                  coff = 0;
-                }
+              roff = 0;
+              coff = k;
+            }
+          else if (k < 0)
+            {
+              k = -k;
+              roff = k;
+              coff = 0;
+            }
 
-              if (nr == 1)
-                {
-                  int n = nc + k;
-                  galois r (n, n, 0, m.m (), m.primpoly ());
-                  for (int i = 0; i < nc; i++)
-                    r (i+roff, i+coff) = m (0, i);
-                  retval = new octave_galois (r);
-                }
-              else
-                {
-                  int n = nr + k;
-                  galois r (n, n, 0, m.m (), m.primpoly ());
-                  for (int i = 0; i < nr; i++)
-                    r (i+roff, i+coff) = m (i, 0);
-                  retval = new octave_galois (r);
-                }
+          if (nr == 1)
+            {
+              int n = nc + k;
+              galois r (n, n, 0, m.m (), m.primpoly ());
+              for (int i = 0; i < nc; i++)
+                r (i+roff, i+coff) = m (0, i);
+              retval = new octave_galois (r);
             }
           else
             {
-              galois r = m.diag (k);
-              if (r.numel () > 0)
-                retval = new octave_galois (r);
+              int n = nr + k;
+              galois r (n, n, 0, m.m (), m.primpoly ());
+              for (int i = 0; i < nr; i++)
+                r (i+roff, i+coff) = m (i, 0);
+              retval = new octave_galois (r);
             }
         }
       else
-        OCTAVE__ERR_WRONG_TYPE_ARG ("gdiag", a);
+        {
+          galois r = m.diag (k);
+          if (r.numel () > 0)
+            retval = new octave_galois (r);
+        }
     }
   return retval;
 }
@@ -390,27 +385,23 @@ matrix must match the total number of elements in the new matrix.\n\
  \
       int dim = (nargin == 1 ? -1 : args(1).int_value (true) - 1); \
  \
-      if (! error_state) \
+      if (dim <= 1 && dim >= -1) \
         { \
-          if (dim <= 1 && dim >= -1) \
+          if (galois_type_loaded && (arg.type_id () == \
+                                     octave_galois::static_type_id ())) \
             { \
-              if (galois_type_loaded && (arg.type_id () == \
-                                         octave_galois::static_type_id ())) \
-                { \
-                  galois tmp = ((const octave_galois&)arg.get_rep ()).galois_value (); \
+              galois tmp = ((const octave_galois&)arg.get_rep ()).galois_value (); \
  \
-                  if (! error_state) \
-                    retval(0) = new octave_galois (tmp.FCN (dim)); \
-                } \
-              else \
-                { \
-                  OCTAVE__ERR_WRONG_TYPE_ARG (#FCN, arg); \
-                  return retval; \
-                } \
+              retval(0) = new octave_galois (tmp.FCN (dim)); \
             } \
           else \
-            error (#FCN ": invalid dimension argument = %d", dim + 1); \
+            { \
+              OCTAVE__ERR_WRONG_TYPE_ARG (#FCN, arg); \
+              return retval; \
+            } \
         } \
+      else \
+        error (#FCN ": invalid dimension argument = %d", dim + 1); \
     } \
   else \
     print_usage (); \
@@ -1017,32 +1008,29 @@ lower triangular matrix. The matrix @var{a} can be rectangular.\n\
       return retval;
     }
 
-  if (! error_state)
+  galoisLU fact (m);
+
+  switch (nargout)
     {
-      galoisLU fact (m);
+    case 0:
+    case 1:
+    case 2:
+      {
+        // While we don't have sparse galois matrices converting the
+        // permutation matrix to a full matrix is the best we can do.
+        Matrix P = Matrix (fact.P ());
+        galois L = P.transpose () * fact.L ();
+        retval(1) = new octave_galois (fact.U ());
+        retval(0) = new octave_galois (L);
+      }
+      break;
 
-      switch (nargout)
-        {
-        case 0:
-        case 1:
-        case 2:
-          {
-            // While we don't have sparse galois matrices converting the
-            // permutation matrix to a full matrix is the best we can do.
-            Matrix P = Matrix (fact.P ());
-            galois L = P.transpose () * fact.L ();
-            retval(1) = new octave_galois (fact.U ());
-            retval(0) = new octave_galois (L);
-          }
-          break;
-
-        case 3:
-        default:
-          retval(2) = fact.P ();
-          retval(1) = new octave_galois (fact.U ());
-          retval(0) = new octave_galois (fact.L ());
-          break;
-        }
+    case 3:
+    default:
+      retval(2) = fact.P ();
+      retval(1) = new octave_galois (fact.U ());
+      retval(0) = new octave_galois (fact.L ());
+      break;
     }
 
   return retval;
@@ -1104,21 +1092,18 @@ ill-conditioned matrix if the reciprocal condition number is small.\n\
       return retval;
     }
 
-  if (! error_state)
-    {
-      int info;
-      double rcond = 0.0;
+  int info;
+  double rcond = 0.0;
 
-      galois result = m.inverse (info, 1);
+  galois result = m.inverse (info, 1);
 
-      if (nargout > 1)
-        retval(1) = rcond;
+  if (nargout > 1)
+    retval(1) = rcond;
 
-      retval(0) = new octave_galois (result);
+  retval(0) = new octave_galois (result);
 
-      if (nargout < 2 && info == -1)
-        warning ("inverse: matrix singular to machine precision, rcond = %g", rcond);
-    }
+  if (nargout < 2 && info == -1)
+    warning ("inverse: matrix singular to machine precision, rcond = %g", rcond);
 
   return retval;
 }
