@@ -18,23 +18,58 @@
 // program with any Open Source program, as defined by the Open Source
 // Initiative (www.opensource.org)
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 
-#include <octave/config.h>
+#include <octave/oct.h>
 #include <octave/byte-swap.h>
+#ifdef HAVE_OCTAVE_GRIPES_H
 #include <octave/gripes.h>
+#endif
+#ifdef HAVE_OCTAVE_ERRWARN_H
+#include <octave/errwarn.h>
+#endif
 #include <octave/lo-ieee.h>
-#include <octave/oct-hdf5.h>
 #include <octave/oct-locbuf.h>
+
+#ifdef HAVE_OCTAVE_OVL_H
+#include <octave/ovl.h>
+#elif HAVE_OCTAVE_OCT_OBJ_H
 #include <octave/oct-obj.h>
+#endif
 #include <octave/ov.h>
 #include <octave/pr-output.h>
 
-#include <octave/ls-oct-ascii.h>
+#if defined(HAVE_OCTAVE_LS_OCT_TEXT_H)
+#  include <octave/ls-oct-text.h>
+#else
+#  include <octave/ls-oct-ascii.h>
+#endif
 
 #include "galois.h"
 #include "ov-galois.h"
 
+#if defined (HAVE_HDF5)
+#  if defined (HAVE_HDF5_H)
+#    include <hdf5.h>
+#  endif
+#  if defined (HAVE_OCTAVE_OCT_HDF5_TYPES_H)
+#    include "oct-hdf5-types.h"
+#  endif
+#  if defined (OCTAVE_ENABLE_64)
+#    define H5T_NATIVE_IDX H5T_NATIVE_INT64
+#  else
+#    define H5T_NATIVE_IDX H5T_NATIVE_INT
+#  endif
+#endif
+
+#if ! defined (X_CAST)
+#  define X_CAST(T, E) (T) (E)
+#endif
+
 #if defined (DEFINE_OCTAVE_ALLOCATOR)
 DEFINE_OCTAVE_ALLOCATOR (octave_galois);
 #endif
@@ -173,8 +208,7 @@ octave_galois::subsref (const std::string &type,
       panic_impossible ();
     }
 
-  if (! error_state)
-    retval = retval.next_subsref (type, idx, skip);
+  retval = retval.next_subsref (type, idx, skip);
 
   return retval;
 }
@@ -313,13 +347,13 @@ octave_galois::double_value (bool) const
 
   if (rows () > 0 && columns () > 0)
     {
-      gripe_implicit_conversion ("Octave:array-as-scalar",
+      OCTAVE__WARN_INVALID_CONVERSION ("Octave:array-as-scalar",
                                  "real matrix", "real scalar");
 
       retval = (double) gval (0, 0);
     }
   else
-    gripe_invalid_conversion ("galois", "real scalar");
+    OCTAVE__ERR_INVALID_CONVERSION ("galois", "real scalar");
 
   return retval;
 }
@@ -333,13 +367,13 @@ octave_galois::complex_value (bool) const
 
   if (rows () > 0 && columns () > 0)
     {
-      gripe_implicit_conversion ("Octave:array-as-scalar",
+      OCTAVE__WARN_INVALID_CONVERSION ("Octave:array-as-scalar",
                                  "real matrix", "real scalar");
 
       retval = (double) gval (0, 0);
     }
   else
-    gripe_invalid_conversion ("galois", "complex scalar");
+    OCTAVE__ERR_INVALID_CONVERSION ("galois", "complex scalar");
 
   return retval;
 }
@@ -392,14 +426,9 @@ octave_galois::assign (const octave_value_list& idx,
     case 2:
       {
         idx_vector i = idx (0).index_vector ();
+        idx_vector j = idx (1).index_vector ();
 
-        if (! error_state)
-          {
-            idx_vector j = idx (1).index_vector ();
-
-            if (! error_state)
-              gval.assign (i, j, rhs);
-          }
+        gval.assign (i, j, rhs);
       }
       break;
 
@@ -407,8 +436,7 @@ octave_galois::assign (const octave_value_list& idx,
       {
         idx_vector i = idx (0).index_vector ();
 
-        if (! error_state)
-          gval.assign (i, rhs);
+        gval.assign (i, rhs);
       }
       break;
 
@@ -520,7 +548,7 @@ octave_galois::save_binary (std::ostream& os, bool& save_as_floats)
 
 bool
 octave_galois::load_binary (std::istream& is, bool swap,
-                            oct_mach_info::float_format fmt)
+                            OCTAVE_MACH_INFO_FLOAT_FORMAT fmt)
 {
   char mord;
   int32_t prim, mdims;
@@ -562,7 +590,7 @@ octave_galois::load_binary (std::istream& is, bool swap,
       Matrix m (dv(0), dv(1));
       double *re = m.fortran_vec ();
       read_doubles (is, re, X_CAST (save_type, tmp), dv.numel (), swap, fmt);
-      if (error_state || ! is)
+      if (! is)
         return false;
 
       gval = galois (m, mord, prim);
